[ -z "$ROOT" ] && ROOT=/www
CONFIG=$ROOT/config
SCRIPT=$ROOT/script

source $SCRIPT/utils/misc.sh

log="logger -t monitor"

retry() {
	sh -c "sleep 20 && $SCRIPT/monitor-config.sh" 2>/dev/null >/dev/null &
	exit 0
}

checkExit() {
	[ -f /tmp/booted ] || retry
	[ -f /tmp/applying ] && retry
	[ -f /tmp/installing ] && retry
}

monitorConfig() {
	checkExit
	local validConfig=`cat $CONFIG/ng.conf | grep HASH_CONFIG_SITE`
	if [ -z "$validConfig" ] ; then
		echo >> $CONFIG/ng.conf
	 	sh $SCRIPT/update/update-ng-config.sh
		exit 0
	fi

	checkExit
  cat /etc/config/network | sort > /tmp/network
	local curHash=`md5 /tmp/network`

	sleep 5
	checkExit
	sh $SCRIPT/setup/setup-network.sh
	uci commit
  cat /etc/config/network | sort > /tmp/network
	local newHash1=`md5 /tmp/network`

	sleep 5
	checkExit
	sh $SCRIPT/setup/setup-network.sh
	uci commit
  cat /etc/config/network | sort > /tmp/network
	local newHash2=`md5 /tmp/network`

	if [ "$newHash1" == "$newHash2" ] ; then
		$log -p warn "network config may in inconsistent state, reload now"
		[ "$newHash1" != "$curHash" ] && /etc/init.d/network reload
	else
		retry
	fi
}

monitorConfig