JSON = (loadfile "/www/web/wifi/JSON.lua")()

local confFile = "/www/config/mobile.conf"
local function applyConfig(config)
  local cmd = table2Qs(config, " ", "=", true) .. " /www/script/update/update-mobile-config.sh"
  pcall(cmdCall, cmd)
end

local function readConfig()
  _G["MOBILE_APN"] = nil
  _G["MOBILE_USERNAME"] = nil
  _G["MOBILE_PASSWORD"] = nil
  _G["MOBILE_PIN"] = nil

  if fileExists(confFile) then
    dofile "/www/config/mobile.conf"
  end

  return {
    apn = _G["MOBILE_APN"] or "",
    username = _G["MOBILE_USERNAME"] or "",
    password = _G["MOBILE_PASSWORD"] or "",
    pin = _G["MOBILE_PIN"] or ""
  }
end

local function getDeviceStatus()
  local cmd = "json=true /www/script/report/stats.sh"
  local success, out = pcall(cmdCall, cmd)
  return out
end

local function getMobileStatus()
  local cmd = "json=true /www/script/report/mobile.sh"
  local success, out = pcall(cmdCall, cmd)
  return out
end

local htmlTpl = "/www/web/mobile/index.html"
local function render(env, options)
  options = options or {}
  options.config = JSON:encode(readConfig())
  options.stats = getDeviceStatus()
  options.mobile = getMobileStatus()
  log(options)
  renderHtml(htmlTpl, options)
end

local function renderError(env)
  renderHtml(htmlTpl, { error = "Thông tin không hợp lệ" })
end

local providers = {
  ["v-connect"] = function(data)
    data["apn"] = "v-connect"
  end,
  ["e-connect"] = function(data)
    data["apn"] = "e-connect"
  end,
  ["v-internet"] = function(data)
    data["apn"] = "v-internet"
  end,
  ["m-wap"] = function(data)
    data["apn"] = "m-wap"
    data["username"] = "mms"
    data["password"] = "mms"
  end,
  ["m3-world"] = function(data)
    data["apn"] = "m3-world"
    data["username"] = "mms"
    data["password"] = "mms"
  end,
  ["internet"] = function(data)
    data["apn"] = "internet"
  end
}

function validateStr(str)
  if type(str) ~= "string" then return false end
  local matched = string.match(str, "^[0-9a-z\-]*$")
  if not matched or string.len(matched) ~= string.len(str) then return false end
  return true
end

function validatePin(str)
  if type(str) ~= "string" then return false end
  local matched = string.match(str, "^%d%d%d%d$")
  if not matched or string.len(matched) ~= string.len(str) then return false end
  return true
end

local function normalizeInput(body)
  local data = {apn = "", username = "", password = "", pin = ""}

  if type(providers[body.provider]) == "function" then
    providers[body.provider](data)
  else
    if body.apn == "" or not validateStr(body.apn) then return nil end
    if validateStr(body.username) then data.username = body.username end
    if validateStr(body.password) then data.password = body.password end
    data.apn = body.apn
  end

  if validatePin(body.pin) then data.pin = body.pin end

  return data
end

local function update(env)
  local rawBody = ""
  local postLength = tonumber(env.CONTENT_LENGTH or 0)
  if postLength > 0 then
    rawBody = io.read(postLength)
  end

  local body = parseQueryString(rawBody)
  local data = normalizeInput(body)
  if not data then
    return renderError(env)
  end

  applyConfig(data)
  render(env)
end

function process(env)
  if env.REQUEST_METHOD == "POST" then
    return update(env)
  end

  return render(env)
end
